pub fn load_json<T: DeserializeOwned>(
path: impl AsRef<Path>,
) -> Result<T, FaucetError>Expand description
Load a config struct from a JSON file.
The file contents are read and deserialized into T.
pub fn load_json<T: DeserializeOwned>(
path: impl AsRef<Path>,
) -> Result<T, FaucetError>Load a config struct from a JSON file.
The file contents are read and deserialized into T.