pub struct Difference {
pub key: Value,
pub kind: DifferenceKind,
}Expand description
One differing key.
Fields
key: ValueThe key columns and their values (from whichever side has the row).
kind: DifferenceKindImplementations
Sourceimpl Difference
impl Difference
Sourcepub fn needs_upsert(&self) -> bool
pub fn needs_upsert(&self) -> bool
Whether repairing this difference means writing the source row.
Sourcepub fn needs_delete(&self) -> bool
pub fn needs_delete(&self) -> bool
Whether repairing this difference means deleting the destination row.