pub fn parse_token(s: &str) -> Option<u64>Expand description
Parse the numeric sequence from a token produced by format_token or
format_token_with_bookmark. Returns None on garbage.
pub fn parse_token(s: &str) -> Option<u64>Parse the numeric sequence from a token produced by format_token or
format_token_with_bookmark. Returns None on garbage.