pub struct StringSummary {
pub count: u64,
pub len_min: u64,
pub len_max: u64,
pub len_mean: f64,
}Expand description
Summary of the string values a column held (character lengths).
Fields
count: u64len_min: u64len_max: u64len_mean: f64Trait Implementations
Sourceimpl Clone for StringSummary
impl Clone for StringSummary
Sourceimpl Debug for StringSummary
impl Debug for StringSummary
Sourceimpl<'de> Deserialize<'de> for StringSummary
impl<'de> Deserialize<'de> for StringSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StringSummary
impl JsonSchema for StringSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StringSummary
impl PartialEq for StringSummary
Sourceimpl Serialize for StringSummary
impl Serialize for StringSummary
impl StructuralPartialEq for StringSummary