Crate faucet_core

Crate faucet_core 

faucet-core

Shared types, traits, and utilities for the faucet-stream ecosystem.

This crate provides the common foundation used by all faucet source and sink connectors:

Re-exports

pub use error::FaucetError;
pub use pipeline::Pipeline;
pub use pipeline::PipelineResult;
pub use pipeline::run_stream;
pub use replication::ReplicationMethod;
pub use traits::Sink;
pub use traits::Source;
pub use transform::RecordTransform;
pub use schemars;
pub use serde_json;

Modules

config
Configuration loading utilities.
error
Error types for faucet-stream.
pipeline
Source-to-sink pipeline orchestration.
replication
Incremental replication support.
schema
JSON Schema inference from record samples.
traits
Shared traits for faucet sources and sinks.
transform
Record transformation pipeline.
util
Shared utilities used across faucet source and sink crates.

Macros

json
Construct a serde_json::Value from a JSON literal.
schema_for
Generates a Schema for the given type using default settings. The default settings currently conform to JSON Schema 2020-12, but this is liable to change in a future version of Schemars if support for other JSON Schema versions is added.

Enums

Value
Represents any valid JSON value.

Traits

JsonSchema
A type which can be described as a JSON Schema document.

Attribute Macros

async_trait

Derive Macros

JsonSchema
Derive macro for JsonSchema trait.